@@ -1,4 +1,9 @@
 #![cfg_attr(feature = "internal_benches", allow(unstable_features), feature(test))]
 
 pub mod g3;
-pub mod sm3;
\ No newline at end of file
+pub mod g4;
+
+pub mod sm3;
+pub mod sm4;
+
+pub mod utils;
